@@ -30,8 +30,8 @@ from context import *
 data_path.mkdir(exist_ok=True, parents=True)
 logger = log.custom_logger(__name__)
 
-def nsrdb(lat, lng, year, filename=None, force_download=False,
-          verbose=False, **kwargs):
+
+def nsrdb(lat, lng, year, filename=None, force_download=False, verbose=False, **kwargs):
     """ NSRDB data
 
     This function pre-process the request.
@@ -59,13 +59,14 @@ def nsrdb(lat, lng, year, filename=None, force_download=False,
         data (pd.DataFrame):
             Radiation dataDescription of return value
     """
-    site_info = {'lat': lat,
-                 'lng': lng,
-                 'force_download': force_download,
-                 'year': str(year),
-                 'filename': filename,
-                 'verbose': verbose
-                }
+    site_info = {
+        "lat": lat,
+        "lng": lng,
+        "force_download": force_download,
+        "year": str(year),
+        "filename": filename,
+        "verbose": verbose,
+    }
 
     # Include kwargs to dictionary
     site_info.update(kwargs)
@@ -77,9 +78,18 @@ def nsrdb(lat, lng, year, filename=None, force_download=False,
 
     return data
 
-def get_nsrdb_data(lat, lng, year, filename=None, path=data_path,
-                   force_download=False, timeseries=True,
-                   meta=False,  **kwargs):
+
+def get_nsrdb_data(
+    lat,
+    lng,
+    year,
+    filename=None,
+    path=data_path,
+    force_download=False,
+    timeseries=True,
+    meta=False,
+    **kwargs,
+):
     """ Get the solar radiation data
 
     Calls request_nsrdb_data if data is not found in path.
@@ -112,13 +122,14 @@ def get_nsrdb_data(lat, lng, year, filename=None, path=data_path,
 
     # If you don't provide a filename use lat and lng.
     if not filename:
-        filename = f'{lat:.4f}_{lng:.4f}.csv'
-        logger.warning('No filename provided.'
-                       'Using Longitude and latitude for filename instead')
+        filename = f"{lat:.4f}_{lng:.4f}.csv"
+        logger.warning(
+            "No filename provided." "Using Longitude and latitude for filename instead"
+        )
     else:
         # Include .csv to filename if it does not have it.
-        if filename[-4:] != '.csv':
-            filename = filename + '.csv'
+        if filename[-4:] != ".csv":
+            filename = filename + ".csv"
 
     timeseries_path, meta_path = _create_data_folder(path, year=year)
     timeseries_filename = timeseries_path.joinpath(filename)
@@ -130,29 +141,43 @@ def get_nsrdb_data(lat, lng, year, filename=None, path=data_path,
 
     # If force download or file does not exists
     if force_download or not timeseries_filename.is_file():
-        logger.info('Downloading timeseries from NSRDB.')
-        request_nsrdb_data(lat, lng, year,
-                           timeseries_filename=timeseries_filename,
-                           meta_path=meta_path, **kwargs)
-        logger.info(f'Data created in {timeseries_filename}')
+        logger.info("Downloading timeseries from NSRDB.")
+        request_nsrdb_data(
+            lat,
+            lng,
+            year,
+            timeseries_filename=timeseries_filename,
+            meta_path=meta_path,
+            **kwargs,
+        )
+        logger.info(f"Data created in {timeseries_filename}")
     else:
-        logger.info(f'File found in {timeseries_filename}')
+        logger.info(f"File found in {timeseries_filename}")
 
     # If you want metadata only
     if meta:
         file_path = meta_path.joinpath(filename)
         meta = pd.read_csv(meta_path)
-        return (meta)
+        return meta
 
     if timeseries:
         #  data = pd.read_csv(time_series_path + filename + '.csv',  index_col=0)
         data = get_solar_data(file_path=timeseries_filename)
         #  data = check_nsrdcb(data)
-        return (data)
+        return data
 
 
-def request_nsrdb_data(lat, lng, year, timeseries_filename, meta_path,
-    utc='false', leap_year='false', interval=60, **kwargs):
+def request_nsrdb_data(
+    lat,
+    lng,
+    year,
+    timeseries_filename,
+    meta_path,
+    utc="false",
+    leap_year="false",
+    interval=60,
+    **kwargs,
+):
     """ NRSDB request function
 
     Request the radiation data from the NSRDB API. Default columns requested.
@@ -192,71 +217,75 @@ def request_nsrdb_data(lat, lng, year, timeseries_filename, meta_path,
 
     # TODO: Implement a better way to handle if api_key is not found.
     # Use environment variable if not found in kwargs
-    if not 'api_key' in kwargs:
-        api_key = os.getenv('api_key') #kwargs['api_key'] # Personal API key
+    if not "api_key" in kwargs:
+        api_key = os.getenv("api_key")  # kwargs['api_key'] # Personal API key
     else:
-        api_key = kwargs['api_key']
+        api_key = kwargs["api_key"]
 
     # Raise if api_key not found
     if not api_key:
-        raise NameError('api_key not found. Please included it in .env or manually')
+        raise NameError("api_key not found. Please included it in .env or manually")
 
     # TODO: Include more attributes using kwargs.
-    if not year == 'tmy':
-        attributes = ('ghi,dhi,dni,wind_speed,wind_direction,'
-                      'air_temperature,solar_zenith_angle')
+    if not year == "tmy":
+        attributes = (
+            "clearsky_dhi,",
+            "clearsky_dni,",
+            "clearsky_ghi,",
+            "ghi,dhi,dni,wind_speed,wind_direction,"
+            "air_temperature,solar_zenith_angle",
+        )
     else:
-        logger.info('tmy attributes selected')
-        attributes = ('ghi,dhi,dni,wind_speed,'
-                     'air_temperature')
+        logger.info("tmy attributes selected")
+        attributes = "ghi,dhi,dni,wind_speed," "air_temperature"
 
     # New url to include physical model 3
-    url = 'https://developer.nrel.gov/api/solar/nsrdb_psm3_download.csv'
+    url = "https://developer.nrel.gov/api/nsrdb/v2/solar/psm3-download.csv"
 
     params = {
-        'api_key': api_key,
-        'wkt': f'POINT({lng:.4f} {lat:.4f})',
-        'attributes': attributes,
-        'email': 'mail@gmail.com',
-        'names': year, # Year information
-        'interval' : str(interval),
-        'utc': utc,
-        'leap_year': leap_year,
+        "api_key": api_key,
+        "wkt": f"POINT({lng:.4f} {lat:.4f})",
+        #"attributes": attributes, # I comment this one to return all
+        "email": "mail@gmail.com",
+        "names": year,  # Year information
+        "interval": str(interval),
+        "utc": utc,
+        "leap_year": leap_year,
     }
 
     # Include kwargs in the params
     params.update(kwargs)
 
     # If verbose print params to request
-    if "verbose" in kwargs:
+    if kwargs.get("verbose"):
         pp.pprint(params)
 
     # TODO: Check if the code below is mandatory to make the request.
     # headers = {
-        # 'content-type': "application/x-www-form-urlencoded",
-        # 'cache-control': "no-cache"
+    # 'content-type': "application/x-www-form-urlencoded",
+    # 'cache-control': "no-cache"
     # }
 
     # Make the request
     response = requests.get(url, params=params)
-    logger.info(f'API Response: {response.status_code}')
+    logger.info(f"API Response: {response.status_code}")
     try:
-        # Check if limit in response headers
-        limit = int(response.headers['X-RateLimit-Remaining'])
-        logger.info(f'Request limit: {limit}')
+        #  Check if limit in response headers
+        limit = int(response.headers["X-RateLimit-Remaining"])
+        logger.info(f"Request limit: {limit}")
         if limit <= 10:
-            logger.warning(f'You almost reach the daily limit. Be careful!')
+            logger.warning(f"You almost reach the daily limit. Be careful!")
     except KeyError:
-        # TODO: Catch this error
+        #  TODO: Catch this error
         pass
 
     # Check if response succeded.
     if response.status_code != 200:
         # Exit program if response different from 200 and print response.
-        logger.error('Data downloading failed. Check API.')
-        print (response.text)
-        print (response.status_code)
-        print (response.reason)
+        logger.error("Data downloading failed. Check API.")
+        print(response.text)
+        print(response.status_code)
+        print(response.reason)
         sys.exit(1)
     else:
         # Read data from response with index col to avoid deleting index
@@ -275,13 +304,15 @@ def request_nsrdb_data(lat, lng, year, timeseries_filename, meta_path,
 
 
 if __name__ == "__main__":
-    site_info = {'lat': 33.21,
-                 'lng': -97.12,
-                 'force_download': True,
-                 'year': str(2012),
-                 'verbose': True,
-                 'interval': 60
-                }
+    site_info = {
+        "lat": 33.21,
+        "lng": -97.12,
+        "force_download": True,
+        "year": str(2012),
+        "verbose": True,
+        "interval": 60,
+    }
 
     df = nsrdb(**site_info)
-    print (df.head())
+    print(df.head())
+
